@@ -1,6 +1,7 @@
 import os
 import sys
 import argparse
+import json
 from .api import punctuate
 
 os.environ["TF_CPP_MIN_LOG_LEVEL"] = "3"
@@ -27,7 +28,6 @@ parser.add_argument(
     help="UTF-8 output text file",
 )
 
-
 group = parser.add_mutually_exclusive_group()
 group.add_argument(
     "--birnn",
@@ -49,7 +49,6 @@ def main():
     else:
         model_type = "biRNN"
 
-    print(model_type)
     output_path.write(punctuate(input_path, model_type, format="file"))
 
 
